==> google-cloud-bigquery-logging-1.0.0.tar.gz: google-cloud-bigquery-logging-1.0.0/google/cloud/bigquery_logging/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from google.cloud.bigquery_logging_v1.types.audit_data import AuditData
from google.cloud.bigquery_logging_v1.types.audit_data import BigQueryAcl
from google.cloud.bigquery_logging_v1.types.audit_data import Dataset
from google.cloud.bigquery_logging_v1.types.audit_data import DatasetInfo
from google.cloud.bigquery_logging_v1.types.audit_data import DatasetInsertRequest
from google.cloud.bigquery_logging_v1.types.audit_data import DatasetInsertResponse
from google.cloud.bigquery_logging_v1.types.audit_data import DatasetListRequest
from google.cloud.bigquery_logging_v1.types.audit_data import DatasetName
from google.cloud.bigquery_logging_v1.types.audit_data import DatasetUpdateRequest
from google.cloud.bigquery_logging_v1.types.audit_data import DatasetUpdateResponse
from google.cloud.bigquery_logging_v1.types.audit_data import EncryptionInfo
from google.cloud.bigquery_logging_v1.types.audit_data import Job
from google.cloud.bigquery_logging_v1.types.audit_data import JobCompletedEvent
from google.cloud.bigquery_logging_v1.types.audit_data import JobConfiguration
from google.cloud.bigquery_logging_v1.types.audit_data import JobGetQueryResultsRequest
from google.cloud.bigquery_logging_v1.types.audit_data import JobGetQueryResultsResponse
from google.cloud.bigquery_logging_v1.types.audit_data import JobInsertRequest
from google.cloud.bigquery_logging_v1.types.audit_data import JobInsertResponse
from google.cloud.bigquery_logging_v1.types.audit_data import JobName
from google.cloud.bigquery_logging_v1.types.audit_data import JobQueryDoneResponse
from google.cloud.bigquery_logging_v1.types.audit_data import JobQueryRequest
from google.cloud.bigquery_logging_v1.types.audit_data import JobQueryResponse
from google.cloud.bigquery_logging_v1.types.audit_data import JobStatistics
from google.cloud.bigquery_logging_v1.types.audit_data import JobStatus
from google.cloud.bigquery_logging_v1.types.audit_data import Table
from google.cloud.bigquery_logging_v1.types.audit_data import TableDataListRequest
from google.cloud.bigquery_logging_v1.types.audit_data import TableDataReadEvent
from google.cloud.bigquery_logging_v1.types.audit_data import TableDefinition
from google.cloud.bigquery_logging_v1.types.audit_data import TableInfo
from google.cloud.bigquery_logging_v1.types.audit_data import TableInsertRequest
from google.cloud.bigquery_logging_v1.types.audit_data import TableInsertResponse
from google.cloud.bigquery_logging_v1.types.audit_data import TableName
from google.cloud.bigquery_logging_v1.types.audit_data import TableUpdateRequest
from google.cloud.bigquery_logging_v1.types.audit_data import TableUpdateResponse
from google.cloud.bigquery_logging_v1.types.audit_data import TableViewDefinition

__all__ = (
    "AuditData",
    "BigQueryAcl",
    "Dataset",
    "DatasetInfo",
    "DatasetInsertRequest",
    "DatasetInsertResponse",
    "DatasetListRequest",
    "DatasetName",
    "DatasetUpdateRequest",
    "DatasetUpdateResponse",
    "EncryptionInfo",
    "Job",
    "JobCompletedEvent",
    "JobConfiguration",
    "JobGetQueryResultsRequest",
    "JobGetQueryResultsResponse",
    "JobInsertRequest",
    "JobInsertResponse",
    "JobName",
    "JobQueryDoneResponse",
    "JobQueryRequest",
    "JobQueryResponse",
    "JobStatistics",
    "JobStatus",
    "Table",
    "TableDataListRequest",
    "TableDataReadEvent",
    "TableDefinition",
    "TableInfo",
    "TableInsertRequest",
    "TableInsertResponse",
    "TableName",
    "TableUpdateRequest",
    "TableUpdateResponse",
    "TableViewDefinition",
)

==> google-cloud-bigquery-logging-1.0.5.tar.gz: google-cloud-bigquery-logging-1.0.5/google/cloud/bigquery_logging/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from google.cloud.bigquery_logging_v1.types.audit_data import (
    AuditData,
    BigQueryAcl,
    Dataset,
    DatasetInfo,
    DatasetInsertRequest,
    DatasetInsertResponse,
    DatasetListRequest,
    DatasetName,
    DatasetUpdateRequest,
    DatasetUpdateResponse,
    EncryptionInfo,
    Job,
    JobCompletedEvent,
    JobConfiguration,
    JobGetQueryResultsRequest,
    JobGetQueryResultsResponse,
    JobInsertRequest,
    JobInsertResponse,
    JobName,
    JobQueryDoneResponse,
    JobQueryRequest,
    JobQueryResponse,
    JobStatistics,
    JobStatus,
    Table,
    TableDataListRequest,
    TableDataReadEvent,
    TableDefinition,
    TableInfo,
    TableInsertRequest,
    TableInsertResponse,
    TableName,
    TableUpdateRequest,
    TableUpdateResponse,
    TableViewDefinition,
)

__all__ = (
    "AuditData",
    "BigQueryAcl",
    "Dataset",
    "DatasetInfo",
    "DatasetInsertRequest",
    "DatasetInsertResponse",
    "DatasetListRequest",
    "DatasetName",
    "DatasetUpdateRequest",
    "DatasetUpdateResponse",
    "EncryptionInfo",
    "Job",
    "JobCompletedEvent",
    "JobConfiguration",
    "JobGetQueryResultsRequest",
    "JobGetQueryResultsResponse",
    "JobInsertRequest",
    "JobInsertResponse",
    "JobName",
    "JobQueryDoneResponse",
    "JobQueryRequest",
    "JobQueryResponse",
    "JobStatistics",
    "JobStatus",
    "Table",
    "TableDataListRequest",
    "TableDataReadEvent",
    "TableDefinition",
    "TableInfo",
    "TableInsertRequest",
    "TableInsertResponse",
    "TableName",
    "TableUpdateRequest",
    "TableUpdateResponse",
    "TableViewDefinition",
)
